@@ -14,9 +14,6 @@ import mimetypes
 
 class ServerListenable:
     def __init__(self,host="localhost",port=8080,controls=None):
-        '''@param host: The host location, such as "localhost", "<your computer name", or <"your computer IP address">
-           @param port: The port, on standard 8080
-           @param controls: The controls class, the standard value of none doesn't do anything'''
         self.sckt=socket.socket()
         self.sckt.bind((host,port))
         self.inittasks(host,port)
